@@ -10,7 +10,7 @@ use Scalar::Util qw/blessed/;
 
 use vars qw($DEBUG $CACHE);
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 our %searches = (
 	cities                              => 'cities?',
@@ -309,7 +309,7 @@ sub _parse_xml_result {
 			next if (ref($list) ne "HASH");
 			foreach my $attribute (%{$list}) {
 				next if !defined($list->{$attribute}->[0]);
-				$result[$i]->{$attribute} = $list->{$attribute}->[0];
+				$result[$i]->{$attribute} = (scalar @{$list->{$attribute}} == 1 ? $list->{$attribute}->[0] : $list->{$attribute});
 				}
 			$i++;
 			}
